from setuptools import setup

setup(
    name='wizata-dsapi',
    version='0.0.10',
    description='Wizata Data Science Toolkit',
    author='Wizata S.A.',
    author_email='info@wizata.com',
    packages=['wizata_dsapi_entities','wizata_dsapi_tools'],
)
